.. _whatsnew_0130:

v0.1.3 (September 13, 2018)
===========================

Backwards compatibility fix for timeseries simulation.

* Make sure that all timestamps are returned in outputs (#17)

Contributors
------------

* Marc Anoma
